/*
	Builder Style Manager main editor JS code
	Written by Chris Jean
	Licensed under GPL v2
	
	Version 0.1
*/

var builder_style_manager_stylesheet = {};

var builder_group_selectors = new Array();
var builder_style_manager_loaded = false;
var builder_preview_updates = new Array();
var builder_intialized_color_pickers = new Array();

function builder_refresh_style_preview() {
	jQuery(".styling-option").each(
		function() {
			if('' !== jQuery(this).val())
				builder_update_style_preview(this, true);
		}
	);
	
	builder_update_css_preview();
}

function builder_update_style_preview(node, batch_update) {
	batch_update = ('undefined' !== typeof batch_update) ? batch_update : false;
	
	parsed_node = builder_parse_node(node);
	
	if(false === parsed_node)
		return;
	
	var data = {};
	data[parsed_node['property']] = parsed_node['value'];
	builder_style_manager_stylesheet.update_rule(parsed_node['selector'], data);
	
	builder_update_syncs(parsed_node['group'], parsed_node['property']);
	
	if(false === batch_update)
		builder_update_css_preview();
}

function builder_update_css_preview() {
	jQuery('#builder_css_preview').val(builder_style_manager_stylesheet.get_stylesheet_text());
}

function builder_parse_node(node) {
	if('undefined' === typeof jQuery(node).attr('name'))
		return false;
	
	
	var matches = jQuery(node).attr('name').match(/^([^-]+)-(.+)/);
	
	var node_data = [];
	
	node_data['name'] = jQuery(node).attr('name');
	node_data['group'] = matches[1];
	node_data['property'] = matches[2];
	node_data['value'] = jQuery(node).val();
	
	if('undefined' !== typeof builder_group_selectors[node_data['group']]) {
		node_data['selector'] = builder_group_selectors[node_data['group']];
	}
	else {
		node_data['selector'] = jQuery('#' + node_data['group'] + '-selector').val();
		builder_group_selectors[node_data['group']] = node_data['selector'];
	}
	
	return node_data;
}

function builder_update_syncs(group, property) {
	var syncs_data = jQuery('#' + group + '-' + property + '-sync').val();
	
	if('undefined' === typeof syncs_data)
		return false;
	
	
	var syncs = syncs_data.split(',');
	var val = jQuery('#' + group + '-' + property).val();
	
	for(count = 0; count < syncs.length; count++) {
		var id = syncs[count];
		var cur_val = val;
		
		var matches = id.match(/^(.+)---(.+)/);
		
		if(matches != undefined) {
			id = matches[1];
			
			if('' !== cur_val) {
				var val_matches = val.match(/(\d+)(.+)/);
				
				cur_val = val_matches[1] * matches[2];
				cur_val += val_matches[2];
			}
		}
		
		jQuery('#' + id).val(cur_val);
		builder_update_style_preview(jQuery('#' + id).get(0), true);
	}
	
	builder_update_css_preview();
}

function builder_update_background_option(node) {
	var matches = jQuery(node).attr("name").match(/^(.+)-option$/);
	
	var main_name = matches[1];
	var value = jQuery(node).val();
	
	if(value == 'image') {
		if(builder_style_manager_loaded)
			jQuery("#" + main_name).val(jQuery("#" + main_name + "-backup").val());
		
		jQuery("." + main_name + "-upload-link").show();
	}
	else {
		if((jQuery("#" + main_name).val() != '') && (jQuery("#" + main_name).val() != 'none'))
			jQuery("#" + main_name + "-backup").val(jQuery("#" + main_name).val());
		jQuery("#" + main_name).val(value);
		
		jQuery("." + main_name + "-upload-link").hide();
	}
	
	builder_update_style_preview(jQuery("#" + main_name).get(0));
}

function builder_enable_color_picker(node) {
	if(true === builder_intialized_color_pickers[jQuery(node).attr("name")])
		return;
	
	jQuery(node).unbind('focus');
	
	jQuery(node).ColorPicker(
		{
			onChange: function(color, el) {
				jQuery(el).val(color);
				builder_update_style_preview(el);
			},
			onBeforeShow: function () {
				color = ('' !== this.value) ? this.value : '#9EDCF0';
				jQuery(this).ColorPickerSetColor(color);
			}
		}
	).bind('keyup',
		function() {
			jQuery(this).ColorPickerSetColor(this.value);
		}
	);
	
	builder_intialized_color_pickers[jQuery(node).attr("name")] = true;
}

function builder_load_preview() {
	var url_input = jQuery("#builder_preview_url");
	var url = url_input.val();
	var iframe = '<iframe src="' + url + '" name="style-preview" id="style-preview" frameborder="0"></iframe>';
	
	jQuery(url_input).replaceWith(iframe);
	
	builder_iframe_resize();
	jQuery('#style-preview').load(builder_init_preview_handlers);
}

var builder_init_preview_handlers = function() {
	builder_style_manager_stylesheet = new ITStylesheet({'document': document.getElementById('style-preview').contentWindow.document});
	builder_refresh_style_preview();
	
	jQuery(".styling-option").keyup(
		function() {
			builder_update_style_preview(this);
		}
	);
	jQuery(".styling-option").change(
		function() {
			builder_update_style_preview(this);
		}
	);
	
	jQuery(".background-image-option").change(
		function() {
			builder_update_background_option(this);
		}
	).each(
		function() {
			builder_update_background_option(this);
		}
	);
	
	builder_style_manager_loaded = true;
}

function builder_init_style_editor() {
	builder_load_preview();
	
	jQuery("[name$='-color']").focus(
		function() {
			builder_enable_color_picker(this);
		}
	);
	
	jQuery(".show-hide-wrapper a").click(
		function() {
			var target = jQuery(this).parent().siblings(".show-hide-target");
			
			if(jQuery(target).css("display") == "none") {
				jQuery(target).show();
				jQuery(this).html("(Hide Options)");
			}
			else {
				jQuery(target).hide();
				jQuery(this).html("(Show Options)");
			}
			
			return false;
		}
	);
	
	jQuery("#posts-filter").submit(
		function() {
			jQuery("#posts-filter :input").each(
				function() {
					if('' == jQuery(this).val()) {
						jQuery(this).remove();
					}
				}
			);
		}
	);
	
	jQuery("input[type='submit']:disabled").removeAttr("disabled");
}

jQuery(document).ready(
	function() {
		if(null !== document.getElementById('builder_style_manager-style-preview'))
			builder_init_style_editor();
	}
);

function builder_get_array_values(name) {
	var values = jQuery("input[name='" + name + "[]']").map(
		function() {
			return jQuery(this).val()
		}
	).get();
	
	return values;
}

if(!window.console) {
	window.console = new function() {
		this.log = function(str) {};
		this.dir = function(str) {};
	};
}

function clear_fade_messages() {
	jQuery(document).ready(
		function() {
			setTimeout(
				function() {
					jQuery(".updated.fade").slideUp('slow');
				}, 5000
			);
		}
	);
}
